#![doc(html_logo_url = "https://avatars.githubusercontent.com/u/54848194?v=4")]

//! # BTW I USE ARCH
//!
//! Hello world!

// Globals are declared outside all other scopes.
pub static LANGUAGE: &str = "Rust";
pub const THRESHOLD: i32 = 10;

pub fn array_length(array: &[u8]) -> usize {
    array.len()
}

pub enum Devices {
    Pixelbook,
    Pixel5,
}

pub enum Topics {
    Rust,
    Go,
    WebAssembly,
    Clojure,
    TypeScript,
}

pub mod social {
    pub const Twitter: &str = "btwiuse";
    pub const GitHub: &str = "btwiuse";
}

pub mod BTW {
    pub mod I {
        pub mod USE {
            pub mod ARCH {
            }
        }
    }
}

pub mod title;
pub mod how_to_install_archlinux;

pub mod Español {}
pub mod 日本語 {}

pub use BTW::I::USE::ARCH::*;

pub trait Empty {}

pub trait Any {}

impl Empty for () {}

impl<T: Empty> Any for T {}

pub trait GitHub {}

pub trait Linux {}

pub trait Windows {}

pub trait Clash {}

pub trait MacOS {}

pub trait Rust {}

pub trait 中文 {}
